import {Component, OnInit, Output, ViewChild} from '@angular/core';
import {BusinessComponent} from '../modal/business/business.component';
import {BusinessService} from '../business.service';
import {TreeNodeInterface} from '../../overAll/basic/basic.component';
import {NzMessageService} from 'ng-zorro-antd';
import {color} from '../../app.constants';

@Component({
    selector: 'smart-b-config',
    templateUrl: './b-config.component.html',
    styles: []
})
export class BConfigComponent implements OnInit {
    @ViewChild('smartBusiness') smartBusiness: BusinessComponent;

    sid;  //节点id
    color = color;

    isLoading = false;   //加载中
    dataSet;  //数据list
    expandDataCache = {};

    constructor(private busineSer:BusinessService,private message:NzMessageService) {
    }

    collapse(array: TreeNodeInterface[], data: TreeNodeInterface, $event: boolean): void {
        if ($event === false) {
            if (data.children) {
                data.children.forEach(d => {
                    const target = array.find(a => a.host === d.host);
                    target.expand = false;
                    this.collapse(array, target, false);
                });
            } else {
                return;
            }
        }
    }

    convertTreeToList(root: any, groupId: string, index): TreeNodeInterface[] {
        const stack = [];
        const array = [];
        const hashMap = {};
        if (root.host == index) {
            stack.push({...root, level: 0, expand: true});
        } else {
            stack.push({...root, level: 0, expand: false});
        }
        while (stack.length !== 0) {
            const node = stack.pop();

            this.visitNode(node, hashMap, array);
            if (node.list) {
                for (let i = node.list.length - 1; i >= 0; i--) {
                    stack.push({...node.list[i], level: node.level + 1, expand: true, parent: node, gId: groupId, checked: false});
                }
            }
        }

        return array;
    }

    visitNode(node: TreeNodeInterface, hashMap: object, array: TreeNodeInterface[]): void {
        if (!hashMap[node.host]) {
            hashMap[node.host] = true;
            array.push(node);
        }
    }

    toTree(index) {
        this.dataSet.forEach(item => {
            this.expandDataCache[item.host] = this.convertTreeToList(item, item.id, index);
        });
    }

    ngOnInit() {
        this.getList();
    }

    //查询业务树
    getList(){
        this.isLoading = true;
        const data = {
            "sid":this.sid,
        };
        this.busineSer.findChild(data).subscribe(
            (res)=>{
                this.isLoading = false;
                if(res.errCode == 10000){
                    this.dataSet = res.data;
                    this.dataSet.forEach((e,index)=>{
                        e.service = index;
                        e.checked = false;
                    })
                    this.toTree(null);
                }else{
                    this.message.error(res.errMsg);
                }
            }
        )
    }

    //添加业务
    showAddModal() {
        this.smartBusiness.showModal('添加业务');
    }

}
